OC.L10N.register(
    "calendar",
    {
    "Cheers!" : "Prost!",
    "Calendar" : "Kalenner",
    "Today" : "Haut",
    "Day" : "Dag",
    "Week" : "Woch",
    "Month" : "Mount",
    "Download" : "Eroflueden",
    "Delete" : "Läschen",
    "Share link" : "Link deelen",
    "Share with users or groups" : "Mat Benotzer oder Gruppen deelen",
    "can edit" : "kann änneren",
    "New calendar" : "Neie Kalenner",
    "Cancel" : "Ofbriechen",
    "Automatic" : "Automatesch",
    "Actions" : "Aktiounen",
    "Email" : "Email",
    "Unknown" : "Onbekannt",
    "never" : "Ni",
    "after" : "No",
    "Repeat" : "Widderhuelen",
    "Monday" : "Méindeg",
    "More" : "Méi",
    "Save" : "Späicheren",
    "Update" : "Update",
    "Personal" : "Perséinlech",
    "Details" : "Detailer",
    "Attendees" : "Participanten",
    "Reminders" : "Erennërungen",
    "Close" : "Zoumaachen",
    "Week {number} of {year}" : "Woch {Nummer} vum {Joer}",
    "Daily" : "All Dag",
    "Weekly" : "All Woch",
    "When shared show full event" : "Wann et gedeelt gouf, dann de ganzen Evenement uweisen",
    "When shared show only busy" : "Wann et gedeelt gouf, dann nëmmen als beschäftegt uweisen",
    "When shared hide this event" : "Wann et gedeelt gouf, dann verstopp dëst Evenement",
    "Location" : "Uert",
    "Description" : "Beschreiwung",
    "Mail" : "Mail",
    "Global" : "Global"
},
"nplurals=2; plural=(n != 1);");
